options nocenter linesize=80;

libname save 'H:\bios180\coursepack\SAS-unc-workshop-2008\';

data gamma;
    infile 'H:\bios180\coursepack\SAS-unc-workshop-2008\cgd_dat.dat' missover;
    input id 1-3 center 5-7 +1 random mmddyy6. rx 2. sex 2. age 3. 
	  height 6.1 weight 6.1 inherit 2. steroids 2. propylac 2. 
	  hos_cat 2. futime 4.  (event1-event7) (7*4.);
	  run;

proc contents;
run;
proc print data=gamma(obs=10);
run;

data temp1; set gamma;   *counting process data set;
    drop event1-event7 futime;

    tstart = 0;
    enum  = 1;

    if (event1 NE .) then do;
	tstop = event1;
	status = 1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (event2 NE .) then do;
	tstop = event2;
	status =1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (event3 NE .) then do;
	tstop = event3;
	status =1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (event4 NE .) then do;
	tstop = event4;
	status =1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (event5 NE .) then do;
	tstop = event5;
	status =1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (event6 NE .) then do;
	tstop = event6;
	status =1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (event7 NE .) then do;
	tstop = event7;
	status =1;
	output;
	tstart = tstop;
	enum = enum +1;
	end;

    if (futime > tstart) then do;
	tstop = futime;
	status =0;
	output;
	end;


data save.cgd1;
    set temp1;
    rx1 = rx * (enum=1);
    rx2 = rx * (enum=2);
    rx3 = rx * (enum>2);
 gaptime=tstop-tstart;
 enum3=min(enum,3);
run;

proc print data=save.cgd1(obs=20);
run;


* make the WLW style data set;

data save.cgd2; set gamma;
    drop  event1-event7 futime;

    array event event1-event7;
    do i=1 to 7;
	if (event(i) = .) then do;
	    time = futime;
	    status =0;
	    end;
	else do;
	    time = event(i);
	    status =1;
	    end;
	
	enum =i;
        if (enum=1) then rx1=rx; else rx1=0;
	if (enum=2) then rx2=rx; else rx2=0;
	if (enum>2) then rx3=rx; else rx3=0;

    enum3=enum*(enum=1)+enum*(enum=2)+3*(enum>2);

	if (i=1) then keepdata=1; 
    else if (event(i-1) ne .) then keepdata=1; 
    else keepdata=0;

	output;
	end;
run;

proc print data=save.cgd2(obs=20);
run;

title 'Time to first event';
proc phreg data=save.cgd1;
model tstop*status(0)=rx age inherit steroids;
where enum=1;
run;

title 'Andersen-Gill Intensity Model';
proc phreg data=save.cgd1 covm;
  model (tstart,tstop)*status(0)=rx age inherit steroids;
  id id;
  where tstart < tstop;
run;

title 'PWP2 (conditional model: total time)';
proc phreg data=save.cgd1;
  model (tstart,tstop)*status(0)=rx1-rx3 age1-age3 inherit1-inherit3 steroids1-steroids3;
  age1=age*(enum=1);
  age2=age*(enum=2);
  age3=age*(enum>2);

  inherit1=inherit*(enum=1);
  inherit2=inherit*(enum=2);
  inherit3=inherit*(enum>2);

  steroids1=steroids*(enum=1);
  steroids2=steroids*(enum=2);
  steroids3=steroids*(enum>2);

  strata enum3;
run;

title 'PWP2 (conditional model: total time with common effect)';
proc phreg data=save.cgd1;
  model (tstart,tstop)*status(0)=rx age inherit steroids;
  strata enum3;
run;

title 'PWP3 (conditional model: gap time)';
proc phreg data=save.cgd1;
  model gaptime*status(0)=rx age inherit steroids;
  strata enum3;
run;

title 'Proportional Means Model';
proc phreg data=save.cgd1 covs(aggregate);
  model (tstart,tstop)*status(0)=rx age inherit steroids;
  id id;
  where tstart < tstop;
run;

/*
title 'Wei-Lin-Weissfeld Model with different effects';

proc phreg data=save.cgd2 covs(aggregate);
  model time*status(0)=rx1-rx3 age1-age3 inherit1-inherit3 steroids1-steroids3;
  age1=age*(enum=1);
  age2=age*(enum=2);
  age3=age*(enum>2);

  inherit1=inherit*(enum=1);
  inherit2=inherit*(enum=2);
  inherit3=inherit*(enum>2);

  steroids1=steroids*(enum=1);
  steroids2=steroids*(enum=2);
  steroids3=steroids*(enum>2);

  strata enum3;
  id id;
  treatment: test rx1,rx2,rx3/average e;
run;

title 'Wei-Lin-Weissfeld Model with common effects';
proc phreg data=save.cgd2 covs(aggregate);
  model time*status(0)=rx age inherit steroids;
  strata enum3;
  id id;
run;

/* another way to create data for WLW;
data a;
keep id tstart tstop status rx enum;
retain id tstart 0;
array tt event1-event7;
set gamma;
id+1;
tstart=0;
do over tt;
enum=_i_;
if tt=. then do;
tstop=futime;
status=0;
end;
else do;
tstop=tt;
status=1;
end;
output;
tstart=tstop;
end;
if (tstart<tstop) then delete;
run;

proc print data=a(obs=20);
run;
*/


*/
